@@ -273,7 +273,7 @@ def run_command(cmd, outfile=None, cwd=None, ostream=None, stdin=None, stdout=No
             os.close(rpipe1)
 
     except WindowsError:
-        err = sys.exc_info[1]
+        err = sys.exc_info()[1]
         raise ApplicationError(
             "Could not execute the command: '%s'\n\tError message: %s"
             % (' '.join(_cmd), err) )
